@font-face {
    font-family: 'robotoregular';
    src: url('Roboto-Regular-webfont.eot');
    src: url('Roboto-Regular-webfont.eot?#iefix') format('embedded-opentype'),
         url('Roboto-Regular-webfont.woff') format('woff'),
         url('Roboto-Regular-webfont.ttf') format('truetype'),
         url('Roboto-Regular-webfont.svg#robotoregular') format('svg');
    font-weight: normal;
    font-style: normal;

}
body{ background-color: #252830;}
.container-fluid {padding: 0; }
.pagination {
   
    float: right;
}
.pagination>.active>a, .pagination>.active>a:focus, .pagination>.active>a:hover, .pagination>.active>span, .pagination>.active>span:focus, .pagination>.active>span:hover{background-color:#1DC7EA; border-color:#1DC7EA;}
.navbar-header,#navbar2{padding-right:15px;padding-left:15px; }

.main-panel > .content{ background-color: #252830; border: 0px; }
.footer,.wrapper,.main-panel,.jumbotron{background-color: #252830}

.sidebar{}

.row,.card{background-color: #252830}
.navbar-default .navbar-brand,.navbar-default .navbar-nav > li > a:not(.btn),#navbar1 a:hover{color: #FFF}
.card .title,.card .category, .card label{color: #FFF}

.all-icons [class*="pe-"]{
    font-size: 40px;
}
.all-icons input{
    border: 0;
}
.all-icons .font-icon-detail{
    text-align: center;
    padding: 45px 0px 30px;
    border: 1px solid #e5e5e5;
    border-radius: 6px;
    margin: 15px 0;
}
.all-icons .font-icon-detail input{
    margin: 25px auto 0;
    width: 100%;
    text-align: center;
    display: block;
    color: #aaa;
    font-size: 13px;
}

.card .table tbody td:first-child, .card .table thead th:first-child{padding:8px;}
#tabledetails tbody td {border-bottom: 1px solid #434857; border-left: 0px; border-right: 0px; border-top: 0px;}
#tabledetails tbody td:first-child{}
.sidebar .nav, body > .navbar-collapse .nav{margin-top: 0px}
.navbar .navbar-brand{margin:0px;padding: 0px; padding-top: 20px; margin-top:0px;margin-left: 10px}
.navbar-brand,
.navbar-nav li a {
    
    font-size: 16px;
}


.form-signin {
  max-width: 330px;
  padding: 15px;
  margin: 0 auto;
}
.form-signin .form-signin-heading,
.form-signin .checkbox {
  margin-bottom: 10px;
}
.form-signin .checkbox {
  font-weight: normal;
}
.form-signin .form-control {
  position: relative;
  height: auto;
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
  padding: 10px;
  font-size: 16px;
}
.form-signin .form-control:focus {
  z-index: 2;
}
.form-signin input[type="email"] {
  margin-bottom: -1px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.form-signin input[type="password"] {
  margin-bottom: 10px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.btn-info {
  border-color: #1DC7EA;
  color: #1DC7EA; }
  .btn-info:hover, .btn-info:focus, .btn-info:active, .btn-info.active, .open > .btn-info.dropdown-toggle {
    background-color: transparent;
    color: #42d0ed;
    border-color: #42d0ed; }
  .btn-info.disabled, .btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled.focus, .btn-info.disabled:active, .btn-info.disabled.active, .btn-info:disabled, .btn-info:disabled:hover, .btn-info:disabled:focus, .btn-info:disabled.focus, .btn-info:disabled:active, .btn-info:disabled.active, .btn-info[disabled], .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled].focus, .btn-info[disabled]:active, .btn-info[disabled].active, fieldset[disabled] .btn-info, fieldset[disabled] .btn-info:hover, fieldset[disabled] .btn-info:focus, fieldset[disabled] .btn-info.focus, fieldset[disabled] .btn-info:active, fieldset[disabled] .btn-info.active {
    background-color: transparent;
    border-color: #1DC7EA; }
  .btn-info.btn-fill {
    color: #FFFFFF;
    background-color: #1DC7EA;
    opacity: 1;
    filter: alpha(opacity=100); }
    .btn-info.btn-fill:hover, .btn-info.btn-fill:focus, .btn-info.btn-fill:active, .btn-info.btn-fill.active, .open > .btn-info.btn-fill.dropdown-toggle {
      background-color: #42d0ed;
      color: #FFFFFF; }
    .btn-info.btn-fill .caret {
      border-top-color: #FFFFFF; }
  .btn-info .caret {
    border-top-color: #1DC7EA; }

  .btnleft{margin-right: 20px;}

