{%extends "users/base.html" %}
{% block navi_content %}
    {%include "users/includes/navicontents_admin.html" %}
{% endblock %}
{% block usernavi_content %}
    {%include "users/includes/usernavicontents_admin.html" %}
{% endblock %}

{% block main_content %}
{% block title %}<h4> Create New Admin</h4>{% endblock %}
    <div class="content" >
        <form action="" method="post">
            {% if form.errors %}
                <!-- Error messaging -->
                <div id="errors">
                    <div class="inner">
                        <p>There were some errors in the information you entered. Please correct the following:</p>
                        {{ form.non_field_errors }}
                        <ul>
                            {% for field in form %}
                                {% if field.errors %}<li>{{ field.label }}: {{ field.errors|striptags }}</li>{% endif %}
                            {% endfor %}
                        </ul>
                    </div>
                </div>
                <!-- /Error messaging -->
            {% endif %}
            {% csrf_token %}
            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <label >User ID</label>
                        <input type="text" class="form-control" placeholder="User ID" name="username">
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <label >First Name</label>
                        <input type="text" class="form-control" placeholder="First Name" name="first_name">
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <label >Last Name</label>
                        <input type="text" class="form-control" placeholder="Last Name" name="last_name">
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <label for="email">Email</label>
                        <input type="email" class="form-control" placeholder="" name="email">
                    </div>
                </div>
            </div>

            <button type="submit" class="btn btn-info btn-fill btnleft">Create</button>
        </form>
    </div>
{% endblock%}