<!doctype html>
<html lang="en">
<head>
	{% load static %}

	<meta charset="utf-8" />
	<link rel="icon" type="image/png" href="{% static 'users/assets/img/favicon.ico' %}">
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />

	<title>{{ user.username }} | Home</title>

	<meta content='width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0' name='viewport' />
    <meta name="viewport" content="width=device-width" />


    <!-- Bootstrap core CSS     -->
    <link href="{% static 'users/css/bootstrap.min.css' %}" rel="stylesheet" />

    <!-- Animation library for notifications   -->
    <link href="{% static 'users/css/animate.min.css' %}" rel="stylesheet"/>

    <!--  Light Bootstrap Table core CSS    -->
    <link href="{% static 'users/css/light-bootstrap-dashboard.css' %}" rel="stylesheet"/>

    <link href="{% static 'users/css/style.css' %}" rel="stylesheet" />
    <!--     Fonts and icons     -->
   
    <link href="{% static 'users/css/pe-icon-7-stroke.css' %}" rel="stylesheet" />

    <style>
        @import url('https://fonts.googleapis.com/css?family=Raleway');
        body {
            font-family: 'Raleway';
        }
    </style>

</head>
<body>

<div class="wrapper">
    <div class="sidebar" data-color="black" data-image="{% static 'users/img/sidebar-4.jpg'%}">

    	<div class="sidebar-wrapper">
            <div class="logo">
                
                <a href= "{% url 'index' %}" class="simple-text">
                    <img src="{% static 'users/img/core_omega.png' %}" style="width:50px;">
                </a>
            </div>

        {% block navi_content %}
		{% endblock %}
    	</div>
    </div>

    <div class="main-panel">
        <nav class="navbar navbar-default navbar-fixed">
            <div class="container-fluid">
                <div class="navbar-header" id="navbar1">
                    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navigation-example-2">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                    <p><a class="navbar-brand" href="#">Dashboard</a></p>
                </div>
                <div class="collapse navbar-collapse" id="navbar2">
                   {% block usernavi_content %}
		           {% endblock %}
                </div>
            </div>
        </nav>

        <div class="content">
            <div class="container-fluid">
				{% block main_content %}
				{% endblock %}
                
            </div>


        <footer class="footer">
            <div class="container-fluid">
                <nav class="pull-left">
                    <ul>
                        <li>
                            <a href="{% url 'index' %}">
                                Home
                            </a>
                        </li>
                        <li>
                            <a href="{% url 'index' %}#aboutus">
                                About Us
                            </a>
                        </li>
                        
                    </ul>
                </nav>
                <p class="copyright pull-right">
                    &copy; {% now 'Y' %} <a href="{% url 'index' %}">HexOmega</a>
                </p>
            </div>
        </footer>

    </div>
</div>


</body>

    <!--   Core JS Files   -->
    <script src="{% static 'users/js/jquery-1.10.2.js' %}" type="text/javascript"></script>
	<script src="{% static 'users/js/bootstrap.min.js' %}" type="text/javascript"></script>

	<!--  Checkbox, Radio & Switch Plugins -->
	<script src="{% static 'users/js/bootstrap-checkbox-radio-switch.js' %}"></script>

	<!--  Charts Plugin -->
	<script src="{% static 'users/js/chartist.min.js' %}"></script>

    <!--  Notifications Plugin    -->
    <script src="{% static 'users/js/bootstrap-notify.js' %}"></script>

    
    <!-- Light Bootstrap Table Core javascript and methods for Demo purpose -->
	<script src="{% static 'users/js/light-bootstrap-dashboard.js' %}"></script>

	

</html>
