{% extends "users/base.html" %}
 {% block navi_content %}
		
	{% if user.is_admin == True %}
        {%include "users/includes/navicontents_admin.html" %}
    {% else %}
        {%include "users/includes/navicontents_leader.html" %}
    {% endif %}


{% endblock %}
{% block usernavi_content %}
    
    {% if user.is_admin == True %}
        {%include "users/includes/usernavicontents_admin.html" %}
    {% else %}
        {%include "users/includes/usernavicontents_leader.html" %}
    {% endif %} 
 
{% endblock %}

{% block main_content %}
<div class="header">
    <h4 class="title">Project Log</h4> </div>
                <div class="content col-md-10">
						        
							
									<h2 id="proj_title">{{project_title | safe}}</h2>
									{{ log_data | safe }}

							

							
							
							
							
							
							
						
                        
				</div>

<style>

#main-title {
    margin-left: 45%;
    margin-bottom: 30px;
}

.username {
    font-size: larger;
}

.info-class {
    /* background-color: rgba(12, 170, 212, 0.7); */
    color: black;
    background-color: lightsteelblue;
    padding: 5px 55px;
    margin-bottom: 10px;
    border-radius: 20px;
    font-size: 17px;
    font-family: 'Ubuntu', 'Lucida Grande', 'Lucida Sans Unicode', 'Geneva', 'Verdana', sans-serif;
}

.info-class p {
    font-size: larger;
}

.info-class i {
    float: right;
}

.warning-class {
    /*background-color: rgba(212, 40, 50, 0.5);*/
    background-color: rgba(212, 100, 95, 0.9);
    color: black;
    padding: 3px 55px;
    margin-bottom: 10px;
    border-radius: 20px;
    font-size: 17px;
    font-family: 'Ubuntu', 'Lucida Grande', 'Lucida Sans Unicode', 'Geneva', 'Verdana', sans-serif;
}

.warning-class p {
    font-size: larger;
}

.warning-class i {
    float: right;
}

.success-class {
    /*background-color: rgba(212, 40, 50, 0.5);*/
    background-color: darkseagreen;
    color: black;
    padding: 3px 55px;
    margin-bottom: 10px;
    border-radius: 20px;
    font-size: 17px;
    font-family: 'Ubuntu', 'Lucida Grande', 'Lucida Sans Unicode', 'Geneva', 'Verdana', sans-serif;
}

.success-class p {
    font-size: larger;
}

.success-class i {
    float: right;
}

</style>
{% endblock%}