<!doctype html>
<html lang="en">
<head>
	<meta charset="utf-8" />
	<link rel="icon" type="image/png" href="assets/img/favicon.ico">
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />

	<title>Admin - Users</title>

	<meta content='width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0' name='viewport' />
    <meta name="viewport" content="width=device-width" />


    <!-- Bootstrap core CSS     -->
    <link href="css/bootstrap.min.css" rel="stylesheet" />

    <!-- Animation library for notifications   -->
    <link href="css/animate.min.css" rel="stylesheet"/>

    <!--  Light Bootstrap Table core CSS    -->
    <link href="css/light-bootstrap-dashboard.css" rel="stylesheet"/>

    <link href="css/style.css" rel="stylesheet" />
    <!--     Fonts and icons     -->
   
    <link href="css/pe-icon-7-stroke.css" rel="stylesheet" />

</head>
<body>

<div class="wrapper">
    <div class="sidebar" data-color="black" data-image="img/sidebar-4.jpg">

    	<div class="sidebar-wrapper">
            <div class="logo">
                
                <a href="home.html" class="simple-text">
                    <img src="img/core_omega.png" style="width:50px;">
                </a>
            </div>

            <ul class="nav">
                <li >
                    <a href="admin.html">
                        <i class="pe-7s-home"></i>
                        <p>Home</p>
                    </a>

                </li>
                <li class="active">
                    <a href="user.html">
                        <i class="pe-7s-user"></i>
                        <p>Users</p>
                    </a>
                </li>
                <li>
                    <a href="table.html">
                        <i class="pe-7s-note2"></i>
                        <p>Projects</p>
                    </a>
                </li>
                
            </ul>
    	</div>
    </div>

    <div class="main-panel">
        <nav class="navbar navbar-default navbar-fixed">
            <div class="container-fluid">
                <div class="navbar-header" id="navbar1">
                    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navigation-example-2">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                    <p><a class="navbar-brand" href="#">Users</a></p>
                </div>
                <div class="collapse navbar-collapse" id="navbar2">
                    

                    <ul class="nav navbar-nav navbar-right">
                        
                        <li class="dropdown">
                              <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                    <p>
										Profile
										<b class="caret"></b>
									</p>
                              </a>
                              <ul class="dropdown-menu">
                                <li><a href="#">Edit Profile</a></li>
                                <li><a href="#">Change Password</a></li>
                               
                                
                                
                              </ul>
                        </li>
                        <li>
                            <a href="#">
                                <p>Log out</p>
                            </a>
                        </li>
						
                    </ul>
                </div>
            </div>
        </nav>


        <div class="content">
            <div class="container-fluid">
                <div class="row">
                    
<div class="col-md-12">
                        <div class="card">
                            <div class="header">
                                <h4 class="title">Create User</h4>
                               
                            </div>
                            
                            
                        
                            <div class="content" >
                                <form >
                                    <div class="row"> 
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label >User ID</label>
                                                <input type="text" class="form-control" placeholder="User ID">
                                            </div>
                                        </div>    
                                    </div>

                                    <div class="row"> 
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label >Name</label>
                                                <input type="text" class="form-control" placeholder="Name">
                                            </div>
                                        </div>    
                                    </div>

                                    <div class="row"> 
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label for="email">Email</label>
                                                <input type="email" class="form-control" placeholder="Email">
                                            </div>
                                        </div>    
                                    </div>

                                    <div class="row">
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label>Description</label>
                                                <textarea rows="5" class="form-control" placeholder="Description" ></textarea>
                                            </div>
                                        </div>
                                    </div>

                                    <button type="submit" class="btn btn-info btn-fill btnleft">Create</button>
                                    <button type="submit" class="btn btn-info btn-fill">Cancel</button>
                                    <div class="clearfix"></div>
                                </form>
                                

                            </div>
                        </div>
                    </div>
                    



                
            </div>
        </div>


        

    </div>

    <footer class="footer">
            <div class="container-fluid">
                <nav class="pull-left">
                    <ul>
                        <li>
                            <a href="index.html">
                                Home
                            </a>
                        </li>
                        <li>
                            <a href="index.html#aboutus">
                                About Us
                            </a>
                        </li>
                        
                    </ul>
                </nav>
                <div class="pull-right">
                <p class="copyright">
                    &copy; <script>document.write(new Date().getFullYear())</script> <a href="index.html">HexOmega</a>
                </p>
            </div>
            </div>
        </footer>
</div>


</body>

    <!--   Core JS Files   -->
    <script src="js/jquery-1.10.2.js" type="text/javascript"></script>
	<script src="js/bootstrap.min.js" type="text/javascript"></script>

	<!--  Checkbox, Radio & Switch Plugins -->
	<script src="js/bootstrap-checkbox-radio-switch.js"></script>

	<!--  Charts Plugin -->
	<script src="js/chartist.min.js"></script>

    <!--  Notifications Plugin    -->
    <script src="js/bootstrap-notify.js"></script>

    
    <!-- Light Bootstrap Table Core javascript and methods for Demo purpose -->
	<script src="js/light-bootstrap-dashboard.js"></script>

	

</html>
