<ul class="nav">
                <li class="active">
                    <a href="{% url 'member_home' user.username %}">
                        <i class="pe-7s-home"></i>
                        <p>Home</p>
                    </a>

                </li>
                <li>
                    <a href= "{% url 'task_list' user.username%}">
                        <i class="pe-7s-user"></i>
                        <p>View Assigned Tasks</p>
                    </a>
                </li>
                
                
</ul>
