<ul class="nav navbar-nav navbar-right">
                        
                        <li class="dropdown">
                              <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                    <p>
										Profile
										<b class="caret"></b>
									</p>
                              </a>
                              <ul class="dropdown-menu">
                                <li><a href="{% url 'display_leader' user.username%}">My Profile</a></li>
								<li><a href="{% url 'update_leader' user.username %}">Update My Profile</a></li>
                                    
                              </ul>
							  
                        </li>
						<li>
                            <a href="{% url 'create_member' user.username %}">
                                <p>Create Member</p>
                            </a>
                        </li>
						
                            <li>
                            <a href="{% url 'add_task' user.username %}">
                                <p>Add Task</p>
                            </a>
                        </li>
                                
                       
                        <li>
                            <a href="{% url 'jump_ship' %}">
                                <p>Log out</p>
                            </a>
                        </li>
						
            </ul>