{%extends "users/base.html" %}
 {% block navi_content %}
		 {%include "users/includes/navicontents_leader.html" %}
{% endblock %}
{% block usernavi_content %}
		 {%include "users/includes/usernavicontents_leader.html" %} 

{% endblock %}

{% block main_content %}
	{% csrf_token %}
	<div class="header">
        <h4 class="title">{{ leaderuser.get_full_name }}'s Information</h4>
    </div>
						
	                        <div class="col-md-6">
                            <div class="content table-responsive table-full-width" >

                                <table class="table table-hover table-striped" id="tabledetails">
                                    
                                    <tbody>
                                        <tr> 
                                            <td class="col-xs-3">User Name</td>
                                            <td>{{ leaderuser.username }}</td> 
                                        </tr>
                                        <tr> 
                                            <td>First Name</td>
                                            <td>{{ leaderuser.first_name }}</td> 
                                        </tr>
                                        <tr> 
                                            <td>Last Name</td>
                                            <td>{{ leaderuser.last_name }}</td> 
                                        </tr>
                                        <tr> 
                                            <td>Email</td>
                                            <td>{{ leaderuser.email }}</td> 
                                        </tr>
                                        <tr> 
                                            <td>Biography</td>
                                            <td>{{ leaderuser.bio }}</td> 
                                        </tr>
                                        <tr>
                                            <td>Project</td>
                                            <td>{{ leaderuser.project.name }}</td>
                                        </tr>
                                    </tbody>
                                </table>

                            </div>
                        </div>

{% endblock %}