<ul class="nav navbar-nav navbar-right">
                        
                        <li class="dropdown">
                              <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                    <p>
										Profile
										<b class="caret"></b>
									</p>
                              </a>
                              <ul class="dropdown-menu">
                                <li><a href="{% url 'member_home' user.username %}">My Profile</a></li>
								<li><a href="{% url 'update_member' user.username %}">Update My Profile</a></li>  
                              </ul>
                        </li>
                        <li>
                            <a href="{% url 'jump_ship' %}">
                                <p>Log out</p>
                            </a>
                        </li>
						
            </ul>