{%extends "users/base.html" %}
{% load bootstrap3 %}
{% load i18n %}
{% load static %}
 {% block navi_content %}
		        {%include "users/includes/navicontents_member.html" %}
{% endblock %}
{% block usernavi_content %}
    
		{%include "users/includes/usernavicontents_member.html" %}
    
	
{% endblock %}

{% block main_content %}
	<div class="header">
        <h4 class="title">Update Member</h4>
    </div>
	
<div style="padding: 5% 20%; color: black;">

{% url 'admin:jsi18n' as jsi18nurl %}
<script type="text/javascript" src="{{ jsi18nurl|default:"../../../jsi18n/ "}}"></script>

<fieldset>
    <div class="form-row">
        <form action="" method="POST" class="form">
            {% csrf_token %}
            {% bootstrap_form form %}
            {# form.as_p #}
            {% buttons %}
                <button type="submit" class="btn btn-info btn-fill">
                    Submit
                </button>
            {% endbuttons %}
        </form>
    </div>
</fieldset>

<script type="text/javascript" src="{% static 'spc/jsi18n.js' %}"></script>
<script type="text/javascript" src="/static/admin/js/core.js"></script>
<script type="text/javascript" src="/static/admin/js/calendar.js"></script>
<script type="text/javascript" src="/static/admin/js/admin/DateTimeShortcuts.js"></script>
<script type="text/javascript" src="/static/admin/js/SelectBox.js"></script>
<script type="text/javascript" src="/static/admin/js/SelectFilter2.js"></script>

</div>
						
	                        

{% endblock %}