<ul class="nav">
                <li class="active">
                    <a href="{% url 'display_leader' request.user.username %}">
                        <i class="pe-7s-home"></i>
                        <p>Home</p>
                    </a>

                </li>
                <li>
                    <a href= "{% url 'members_list' request.user.username %}">
                        <i class="pe-7s-users"></i>
                        <p>Members</p>
                    </a>
                </li>
				 <li>
                    <a href= "{% url 'leader_home' request.user.username %}">
                        <i class="pe-7s-display1"></i>
                        <p>View Tasks</p>
                    </a>
                </li>
                <li>
                    <a href="{% url 'leader_log' user.username user.project.name %}">
                        <i class="pe-7s-note2"></i>
                        <p>View Log</p>
                    </a>
                </li>
                
</ul>
