{% block title %}Update Admin Details{% endblock %}
<form action="{% url 'update_admin' adminuser.pk %}" method="post">
    {% csrf_token%}
    {{ form.as_p }}
    <input type="submit" value="Update" />
</form>