<ul class="nav navbar-nav navbar-right">
                        
                        <li class="dropdown">
                              <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                    <p>
										Profile
										<b class="caret"></b>
									</p>
                              </a>
                              <ul class="dropdown-menu">
							   <li><a href="{% url 'display_admin' request.user.username %}"> My Profile </a></li>
                                <li><a href="{% url 'update_admin' request.user.username %}">Update My Profile</a></li>
                                
                              </ul>
                        </li>
						<li>
                            <a href="{% url 'add_admin' user.username %}">
                                <p>Create Admin</p>
                            </a>
                        </li>
                        <li>
                            <a href="{% url 'add_leader' user.username %}">
                                <p>Create Leader</p>
                            </a>
                        </li>
                        <li>
                            <a href="{% url 'jump_ship' %}">
                                <p>Log out</p>
                            </a>
                        </li>
						
            </ul>