# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-27 09:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='role',
            name='title',
            field=models.CharField(max_length=30, unique=True),
        ),
    ]
