<!DOCTYPE html>
<html lang="en">
<head>

    {% load static %}

    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="Project Management Toolkit">
    <meta name="author" content="Jaroi">

    <title>HexOmega - Home</title>

    <!-- Bootstrap Core CSS -->
    <link href="{% static "users/css/bootstrap.min.css" %}" rel="stylesheet">

    <!-- Custom CSS -->
    <link href="{% static "users/css/full-slider.css" %}" rel="stylesheet">
    <link href="{% static "users/css/style.css" %}" rel="stylesheet" />

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
        <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
    <style>
    .navbar-brand,
    .navbar-nav li a {
        line-height: 60px;
        height: 60px;
        padding-top: 0;
        font-size: 16px;
    }
    .navbar-fixed-top
    {
        padding:0;
    /* Permalink - use to edit and share this gradient: http://colorzilla.com/gradient-editor/#555459+0,252830+100 */
    background: rgb(85,84,89); /* Old browsers */
    background: -moz-linear-gradient(top,  rgba(85,84,89,1) 0%, rgba(37,40,48,1) 100%); /* FF3.6-15 */
    background: -webkit-linear-gradient(top,  rgba(85,84,89,1) 0%,rgba(37,40,48,1) 100%); /* Chrome10-25,Safari5.1-6 */
    background: linear-gradient(to bottom,  rgba(85,84,89,1) 0%,rgba(37,40,48,1) 100%); /* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#555459', endColorstr='#252830',GradientType=0 ); /* IE6-9 */
    }
    </style>
</head>

<body>

    <!-- Navigation -->
    <nav class="navbar navbar-inverse navbar-fixed-top" role="navigation">
        <div class="container">
            <!-- Brand and toggle get grouped for better mobile display -->
            <div class="navbar-header">
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1">
                    <span class="sr-only">Toggle navigation</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="{% url 'index' %}" ><img src="{% static "users/img/core_omega.png" %}" style="width:50px; margin-top:-15px; "></a>
            </div>
            <!-- Collect the nav links, forms, and other content for toggling -->
            <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
                <ul class="nav navbar-nav navbar-right">
                    <li>
                        <a href="{% url 'index' %}#aboutus">About Us</a>
                    </li>
                    <li>
                        <a href="{% url 'login_page' %}">Login</a>
                    </li>
                    
                </ul>
            </div>
            <!-- /.navbar-collapse -->
        </div>
        <!-- /.container -->
    </nav>

    <!-- Full Page Image Background Carousel Header -->
    <header id="myCarousel" class="carousel slide">
        <!-- Indicators -->
        <ol class="carousel-indicators">
            <li data-target="#myCarousel" data-slide-to="0" class="active"></li>
            <li data-target="#myCarousel" data-slide-to="1"></li>
            <li data-target="#myCarousel" data-slide-to="2"></li>
        </ol>

        <!-- Wrapper for Slides -->
        <div class="carousel-inner">
            <div class="item active">
                <!-- Set the first background image using inline CSS below. -->
                <div class="fill" style="background-image:url('{% static "users/img/pmt1.png" %}');"></div>
                <div class="carousel-caption">
                    <h2>Managing Project Easy and Efficient</h2>
                </div>
            </div>
            <div class="item">
                <!-- Set the second background image using inline CSS below. -->
                <div class="fill" style="background-image:url('{% static "users/img/pmt2.png" %}');"></div>
                <div class="carousel-caption">
                    <h2>Managing Project Easy and Efficient</h2>
                </div>
            </div>
            <div class="item">
                <!-- Set the third background image using inline CSS below. -->
                <div class="fill" style="background-image:url('{% static "users/img/pmt3.png" %}');"></div>
                <div class="carousel-caption">
                    <h2>Managing Project Easy and Efficient</h2>
                </div>
            </div>
        </div>

        <!-- Controls -->
        <a class="left carousel-control" href="#myCarousel" data-slide="prev">
            <span class="icon-prev"></span>
        </a>
        <a class="right carousel-control" href="#myCarousel" data-slide="next">
            <span class="icon-next"></span>
        </a>

    </header>

    <div class="container">

        <div class="row">
            <div class="col-lg-12" id="aboutus">
                <h2>About HexOmega</h2>
                <p>
HexOmega is project management toolkit system targeting lecturer and students in Murdoch University. HexOmega is the web application that allows users to view the progress and logs of a project, schedule tasks, track progress of individual and functions as a notification system that will notify users of deadlines.
                </p>
            </div>
        </div>

        

        <!-- Footer -->
        <footer>
            <div class="row">
                <div class="col-lg-12">
                    <p class="copyright pull-right">&copy; <script>document.write(new Date().getFullYear())</script> <a href="/">HexOmega</a></p>

                </div>
            </div>
            <!-- /.row -->
        </footer>

    </div>

    <!-- jQuery -->
   <script src="{% static "users/js/jquery-1.10.2.js" %}" type="text/javascript"></script>

    <!-- Bootstrap Core JavaScript -->
    <script src="{% static "users/js/bootstrap.min.js" %}"></script>

    <!-- Script to Activate the Carousel -->
    <script>
    $('.carousel').carousel({
        interval: 5000 //changes the speed
    })
    </script>

</body>

</html>
