{%extends "users/base.html" %}
{% block navi_content %}
    {%include "users/includes/navicontents_admin.html" %}
{% endblock %}
{% block usernavi_content %}	
    {%include "users/includes/usernavicontents_admin.html" %}
{% endblock %}
{% block main_content %}
	{% csrf_token %}
    <div class="header">
        <h4 class="title">{{ user.get_full_name }}'s Information</h4>
    </div>
	
    <div class="col-md-6">
        <div class="content table-responsive table-full-width" >

            <table class="table table-hover table-striped" id="tabledetails">
                                    
                <tbody>
                <tr>
                    <td class="col-xs-3">User Name</td>
                    <td>{{ user.username }}</td>
                </tr>
                <tr>
                    <td>First Name</td>
                    <td>{{ user.first_name }}</td>
                </tr>
                <tr>
                    <td>Last Name</td>
                    <td>{{ user.last_name }}</td>
                </tr>
                <tr>
                    <td>Email</td>
                    <td>{{ user.email }}</td>
                </tr>
                <tr>
                    <td>Biography</td>
                    <td>{{ user.bio }}</td>
                </tr>
                </tbody>
            </table>
			<a href="{% url 'list_of_users' user.username %}" class="btn btn-info btn-fill">&lt;&lt;Back to list of users</a>

        </div>
    </div>

{% endblock %}