<ul class="nav">
                <li class="active">
                    <a href="{% url 'open_project' request.user.username %}">
                        <i class="pe-7s-home"></i>
                        <p>Home</p>
                    </a>

                </li>
                <li>
                    <a href= "{% url 'list_of_users' user.username %}">
                        <i class="pe-7s-user"></i>
                        <p>Users</p>
                    </a>
                </li>
               
                <li>
                    <a href="{% url 'all_project' user.username %}">
                        <i class="pe-7s-note2"></i>
                        <p>Projects</p>
                    </a>
                </li>
				<li>
                    <a href="{% url 'users_search' user.username %}">
                        <i class="pe-7s-search"></i>
                        <p>Users Search</p>
                    </a>
                </li>
                
</ul>