{%extends "users/base.html" %}

{% block navi_content %}
		 {%include "users/includes/navicontents_member.html" %}
{% endblock %}
{% block usernavi_content %}
		 {%include "users/includes/usernavicontents_member.html" %} 

{% endblock %}

{% block main_content %}
                        <div style="list-style-type: none; color: white;">
                        {% if messages %}
                        <ul class="messages">
                            {% for message in messages %}
                            <li{% if message.tags %} class="{{ message.tags }}"{% endif %} style="list-style-type: none">
                                {{ message }}
                            </li>
                            {% endfor %}
                        </ul>
                        {% endif %}
						
						</div>
		{% csrf_token %}				
						  
<div class="header">
        <h4 class="title">{{ memberuser.get_full_name }}</h4>
 </div>
<div class="col-md-6">
        <div class="content table-responsive table-full-width" >

            <table class="table table-hover table-striped" id="tabledetails">
                                    
                <tbody>
                <tr>
                    <td class="col-xs-3">User Name</td>
                    <td>{{ memberuser.username }}</td>
                </tr>
                <tr>
                    <td>First Name</td>
                    <td>{{memberuser.first_name }}</td>
                </tr>
                <tr>
                    <td>Last Name</td>
                    <td>{{ memberuser.last_name }}</td>
                </tr>
                <tr>
                    <td>Email</td>
                    <td>{{ memberuser.email }}</td>
                </tr>
                <tr>
                    <td>Role</td>
                    <td>{{ memberuser.role.title }}</td>
                </tr>
				<tr>
                    <td>Project</td>
                    <td>{{ memberuser.project.name }}</td>
                </tr>
                </tbody>
            </table>

        </div>
    </div> 
		
        

        
    

								
                       
                      
	
	
{% endblock %}